@@ -30,7 +30,7 @@
 #
 #========================================================================
 #
-# Version 4.1.1, released 29 Mar 2017.
+# Version 4.1.2, released 30 Apr 2017.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -63,6 +63,7 @@ sub start
     my(@fileList, $rsyncArgs, $logMsg, $rsyncCmd);
     my $binDir = $t->{bpc}->BinDir();
 
+    alarm(0);
     #
     # We add a slash to the share name we pass to rsync
     #
@@ -96,6 +97,7 @@ sub start
         #
         if ( $remoteDir =~ m{(.*)\Q$t->{pathHdrSrc}\E(/*)$} ) {
             $remoteDir = "$1$2";
+            $remoteDir = "/" if ( $remoteDir eq "" );
             $t->{XferLOG}->write(\"Trimming $t->{pathHdrSrc} from remoteDir -> $remoteDir\n");
         } else {
             for ( my $i = 0 ; $i < @{$t->{fileList}} ; $i++ ) {
@@ -333,6 +335,9 @@ sub start
         if ( $conf->{ClientCharset} ne "" ) {
             push(@$rsyncArgs, "--iconv=utf8,$conf->{ClientCharset}");
         }
+        if ( $conf->{ClientTimeout} > 0 && $conf->{ClientTimeout} =~ /^\d+$/ ) {
+            push(@$rsyncArgs, "--timeout=$conf->{ClientTimeout}");
+        }
 
         if ( $t->{XferMethod} eq "rsync" ) {
             unshift(@$rsyncArgs, "--rsync-path=$conf->{RsyncClientPath}")
@@ -441,7 +446,6 @@ sub start
         #
         # Run the $conf->{RsyncBackupPCPath} command
         #
-	alarm(0);
         print("This is the rsync child about to exec $conf->{RsyncBackupPCPath}\n");
 	$bpc->cmdExecOrEval($rsyncCmd);
         print("cmdExecOrEval failed $?\n");
@@ -453,7 +457,6 @@ sub start
     #from_to($str, $conf->{ClientCharset}, "utf8")
     #                        if ( $conf->{ClientCharset} ne "" );
     $t->{XferLOG}->write(\"Running: $str\n");
-    alarm($conf->{ClientTimeout});
     $t->{_errStr} = undef;
     return $logMsg;
 }
@@ -464,7 +467,7 @@ sub run
     my $conf = $t->{conf};
     my $bpc  = $t->{bpc};
 
-    alarm($conf->{ClientTimeout});
+    alarm(0);
     while ( 1 ) {
         my($mesg, $done);
         if ( sysread($t->{rsyncFd}, $mesg, 32768) <= 0 ) {
@@ -498,7 +501,6 @@ sub run
             #
             # refresh our inactivity alarm
             #
-            alarm($conf->{ClientTimeout}) if ( !$t->{abort} );
             if ( /^log:\s(recv|del\.|send)\s(.{11})\s.{9}\s*\d+,\s*\d+\s*(\d+)\s(.*)/ ) {
                 my $type     = $1;
                 my $changes  = $2;
@@ -532,7 +534,7 @@ sub run
                 next;
             }
             if ( /^__bpc_progress_fileCnt__ \d+/ ) {
-                print("$_\n");
+                print("$_\n") if ( !$t->{noProgressPrint} );
                 $t->{XferLOG}->write(\"$_\n") if ( $conf->{XferLogLevel} >= 6 );
                 next;
             }
